#
# Cookbook Name:: windev
# Recipe:: choco_packages
#
# Copyright (c) 2014-2023 Zühlke, All Rights Reserved.

include_recipe 'windev::depot'

::Chef::Recipe.send(:include, Windows::Helper)

choco_packages=node.fetch('choco_packages',[])

unless choco_packages.empty?
  include_recipe 'chocolatey::default'
end
choco_packages.each do |pkg|
  if pkg["name"]
    pkg_source=pkg.fetch("source","")
    pkg_options=pkg.fetch("options",[])
    pkg_version=pkg.fetch("version","")
    pkg_params=pkg.fetch("params","")

    package_action=:install
    package_action=:upgrade if pkg.fetch("upgrade",false)

    if pkg_options.is_a? String
      # tokenization taken from: https://stackoverflow.com/a/27742127 (CC BY-SA 3.0)
      pkg_options = pkg_options.split(/\s(?=(?:[^'"]|'[^']*'|"[^"]*")*$)/)
        .select {|s| not s.empty? }
        .map {|s| s.gsub(/(^ +)|( +$)|(^["']+)|(["']+$)/,'')}
    end

    if !pkg_params.empty?
      pkg_options = pkg_options.dup
      pkg_options<<"--parameters"
      pkg_options<<pkg_params
    end

    chocolatey_package pkg["name"] do
      version pkg_version unless pkg_version.empty?
      source pkg_source unless pkg_source.empty?
      options pkg_options unless pkg_options.empty?
      returns [0,3010] + pkg.fetch('exit_codes', [])
      action package_action
    end 
  end
end
